@@ -12,9 +12,9 @@ use App::TimelogTxt::Day;
 use App::TimelogTxt::File;
 use App::TimelogTxt::Event;
 
-our $VERSION = '0.03_3';
+our $VERSION = '0.03';
+
 
-# Initial configuration information.
 my %config = (
     editor => '',
     dir    => '',
@@ -22,25 +22,24 @@ my %config = (
 );
 my $config_file = "$ENV{HOME}/.timelogrc";
 
-# Dispatch table for commands
 my %commands = (
     'start' => {
         code     => \&start_event,
         clue     => 'start {event description}',
         abstract => 'Start timing a new event.',
-        help     => 'Stop the current event and start timing a new event.',
+        help     => 'Stop last event and start timing a new event.',
     },
     App::TimelogTxt::Utils::STOP_CMD() => {
         code => sub { my $app = shift; log_event( $app, App::TimelogTxt::Utils::STOP_CMD() ); },
         clue => App::TimelogTxt::Utils::STOP_CMD(),
-        abstract => 'Stop timing the current event.',
-        help     => 'Stop timing the current event.',
+        abstract => 'Stop timing last event.',
+        help     => 'Stop timing last event.',
     },
     'push' => {
         code     => \&push_event,
         clue     => 'push {event description}',
-        abstract => 'Save the current event and start timing new.',
-        help     => 'Save the current event on stack and start timing new event.',
+        abstract => 'Save current event and start timing new.',
+        help     => 'Save last event on stack and start timing new event.',
     },
     'pop' => {
         code     => \&pop_event,
@@ -52,7 +51,7 @@ my %commands = (
         code     => \&drop_event,
         clue     => 'drop [all|{n}]',
         abstract => 'Drop items from stack.',
-        help     => 'Drop one or more events from top of event stack, or all
+        help     => 'Drop one or more items from top of event stack, or all
 if argument supplied.',
     },
     'ls' => {
@@ -99,8 +98,6 @@ if argument supplied.',
     },
 );
 
-# Sub class of App::CmdDispatch that initializes configuration information
-# specific to this program. It also provides access to that configuration.
 {
     package Timelog::CmdDispatch;
     use base 'App::CmdDispatch';
@@ -119,30 +116,18 @@ if argument supplied.',
     {
         my ($self) = @_;
         my $config = $self->get_config();
-        my $home = _home();
 
         $config->{editor} ||= $config{editor} || $ENV{'VISUAL'} || $ENV{'EDITOR'} || '/usr/bin/vim';
-        $config->{dir}    ||= $config{dir} || "$home/timelog";
+        $config->{dir}    ||= $config{dir} || "$ENV{HOME}/timelog";
         $config->{defcmd} ||= $config{defcmd} || App::TimelogTxt::Utils::STOP_CMD();
-        $config->{dir} =~ s/~/$home/;
+        $config->{'dir'} =~ s/~/$ENV{HOME}/;
         foreach my $d ( [qw/logfile timelog.txt/], [qw/stackfile stack.txt/] )
         {
             $config->{ $d->[0] } = "$config->{'dir'}/$d->[1]";
-            $config->{ $d->[0] } =~ s/~/$home/;
+            $config->{ $d->[0] } =~ s/~/$ENV{HOME}/;
         }
         return;
     }
-
-    sub _home
-    {
-        return $ENV{HOME} if defined $ENV{HOME};
-        if( $^O eq 'MSWin32' )
-        {
-            return "$ENV{HOMEDRIVE}$ENV{HOMEPATH}" if defined $ENV{HOMEPATH};
-            return $ENV{USERPROFILE} if defined $ENV{USERPROFILE};
-        }
-        return '/';
-    }
 }
 
 sub run
@@ -173,8 +158,6 @@ or a day name: yesterday, today, or sunday .. saturday.\n",
     return;
 }
 
-# Command handlers
-
 sub log_event
 {
     my $app    = shift;
@@ -191,6 +174,14 @@ sub edit_logfile
     return;
 }
 
+sub _each_logline
+{
+    my ( $app, $code ) = @_;
+    open my $fh, '<', $app->_logfile;
+    $code->() while( <$fh> );
+    return;
+}
+
 sub list_events
 {
     my ( $app, $day ) = @_;
@@ -254,6 +245,56 @@ sub report_hours
     return;
 }
 
+sub extract_day_tasks
+{
+    my ( $app, $day, $eday ) = @_;
+
+    my $stamp = App::TimelogTxt::Utils::day_stamp( $day );
+    die "No day provided.\n" unless defined $stamp;
+    my $estamp = App::TimelogTxt::Utils::day_end( $eday ? App::TimelogTxt::Utils::day_stamp( $eday ) : $stamp );
+    my ( $summary, %last, @summaries );
+    my $event;
+    my $prev_stamp = '';
+
+    open my $fh, '<', $app->_logfile;
+    my $file = App::TimelogTxt::File->new( $fh, $stamp, $estamp );
+
+    while( defined( $_ = $file->readline ) )
+    {
+        eval {
+            $event = App::TimelogTxt::Event->new_from_line( $_ );
+        } or next;
+        if( $prev_stamp ne $event->stamp )
+        {
+            my $new_stamp = $event->stamp;
+            if( $summary and !$event->is_stop() )
+            {
+                $summary->update_dur( \%last, $new_stamp );
+                %last = ();
+            }
+            $summary = App::TimelogTxt::Day->new( $new_stamp );
+            push @summaries, $summary;
+            $prev_stamp = $new_stamp;
+        }
+        $summary->set_start( $event->epoch );
+        $summary->update_dur( \%last, $event->epoch );
+        $summary->start_task( $event );
+        %last = ($event->is_stop() ? () : $event->snapshot );
+    }
+
+    return [] unless $summary;
+
+    my $end_time = ( App::TimelogTxt::Utils::is_today( $day ) and !$event->is_stop() )
+        ? time
+        : App::TimelogTxt::Utils::stamp_to_localtime( $estamp );
+
+    $summary->update_dur( \%last, $end_time );
+
+    return if $summary->is_empty;
+
+    return \@summaries;
+}
+
 sub start_event
 {
     my ( $app, @event ) = @_;
@@ -261,6 +302,13 @@ sub start_event
     return;
 }
 
+sub _stack
+{
+    my ($app) = @_;
+    require App::TimelogTxt::Stack;
+    return App::TimelogTxt::Stack->new( $app->_stackfile );
+}
+
 sub push_event
 {
     my ( $app, @event ) = @_;
@@ -295,79 +343,10 @@ sub list_stack
     my ($app) = @_;
     return unless -f $app->_stackfile;
     my $stack = _stack( $app );
-    $stack->list( \*STDOUT );
+    $stack->list();
     return;
 }
 
-# Extract the daily events from the timelog.txt file and generate the list of Day
-# objects that encapsulates them.
-
-sub extract_day_tasks
-{
-    my ( $app, $day, $eday ) = @_;
-
-    my $stamp = App::TimelogTxt::Utils::day_stamp( $day );
-    die "No day provided.\n" unless defined $stamp;
-    my $estamp = App::TimelogTxt::Utils::day_end( $eday ? App::TimelogTxt::Utils::day_stamp( $eday ) : $stamp );
-    my ( $summary, $last, @summaries );
-    my $prev_stamp = '';
-
-    open my $fh, '<', $app->_logfile;
-    my $file = App::TimelogTxt::File->new( $fh, $stamp, $estamp );
-
-    use Data::Dumper;
-    while( defined( my $line = $file->readline ) )
-    {
-        my $event;
-        eval {
-            $event = App::TimelogTxt::Event->new_from_line( $line );
-        } or next;
-        if( $prev_stamp ne $event->stamp )
-        {
-            my $new_stamp = $event->stamp;
-            if( $summary and !$event->is_stop() )
-            {
-                $summary->update_dur( $last, $event->epoch );
-                $last = undef;
-            }
-            $summary = App::TimelogTxt::Day->new( $new_stamp );
-            push @summaries, $summary;
-            $prev_stamp = $new_stamp;
-        }
-        $summary->update_dur( $last, $event->epoch );
-        $summary->start_task( $event );
-        $last = ($event->is_stop() ? undef : $event );
-    }
-
-    return [] unless $summary;
-    my $end_time = ( App::TimelogTxt::Utils::is_today( $day ) and !($last and $last->is_stop()) )
-        ? time
-        : App::TimelogTxt::Utils::stamp_to_localtime( $estamp );
-
-    $summary->update_dur( $last, $end_time );
-
-    return if $summary->is_empty;
-
-    return \@summaries;
-}
-
-# Utility functions
-
-sub _each_logline
-{
-    my ( $app, $code ) = @_;
-    open my $fh, '<', $app->_logfile;
-    $code->() while( <$fh> );
-    return;
-}
-
-sub _stack
-{
-    my ($app) = @_;
-    require App::TimelogTxt::Stack;
-    return App::TimelogTxt::Stack->new( $app->_stackfile );
-}
-
 sub _get_last_event
 {
     my ( $app ) = @_;
@@ -385,140 +364,107 @@ __END__
 
 App::TimelogTxt - Core code for timelog utility.
 
+
 =head1 VERSION
 
-This document describes App::TimelogTxt version 0.03_3
+This document describes App::TimelogTxt version 0.03
+
 
 =head1 SYNOPSIS
 
     use App::TimelogTxt;
-    App::TimelogTxt::run();
 
+=for author to fill in:
+    Brief code example(s) here showing commonest usage(s).
+    This section will be as far as many users bother reading
+    so make it as educational and exeplary as possible.
+  
+  
 =head1 DESCRIPTION
 
-This module encapsulates all of the functionality of the timelog application.
-This module delegates much of the heavy lifting to other modules. It does
-handle the UI work and the configuration file.
+=for author to fill in:
+    Write a full description of the module and its features here.
+    Use subsections (=head2, =head3) as appropriate.
 
-=head1 INTERFACE
 
-At the moment, the only real interface to this file is the C<run> command.
-In case this becomes more generally useful somehow, I'll go ahead and document
-the other public methods.
+=head1 INTERFACE 
 
-In the methods below, the C<$app> parameter is an object of the class
-C<Timelog::CmdDispatch>. This is a subclass of L<App::CmdDispatch> that adds
-support needed for some of our configuration.
+=for author to fill in:
+    Write a separate section listing the public components of the modules
+    interface. These normally consist of either subroutines that may be
+    exported, or methods that may be called on objects belonging to the
+    classes provided by the module.
 
-=head2 run()
 
-=head2 log_event( $app, @event );
+=head1 DIAGNOSTICS
 
-Add the specified event to the end of timelog.txt
+=for author to fill in:
+    List every single error and warning message that the module can
+    generate (even the ones that will "never happen"), with a full
+    explanation of each problem, one or more likely causes, and any
+    suggested remedies.
 
-=head2 edit_logfile( $app )
+=over
 
-Implementation of the 'edit' command.
+=item C<< Error message here, perhaps with %s placeholders >>
 
-=head2 list_events( $app, $day )
+[Description of error here]
 
-Implementation of the 'ls' command.
+=item C<< Another error message here >>
 
-=head2 list_projects( $app )
+[Description of error here]
 
-Implementation of the 'lsproj' command.
-
-=head2 daily_report( $app, $day, $end_day )
-
-Implementation of the 'report' command.
-
-=head2 daily_summary( $app, $day, $end_day )
-
-Implementation of the  'summary' command.
-
-=head2 report_hours( $app, $day, $end_day )
-
-Implementation of the 'hours' command.
-
-=head2 extract_day_tasks( $app, $day, $end_day )
-
-Read the timelog.txt file and create an array of L<App::TimelogTxt::Day>
-objects that contain the information for the days from C<$day> to C<$end_day>.
-
-=head2 start_event( $app, @event )
-
-Implementation of the 'start' command.
-
-=head2 push_event( $app, @event )
-
-Implementation of the 'push' command.
-
-=head2 pop_event( $app )
-
-Implementation of the 'pop' command.
-
-=head2 drop_event( $app, $arg )
-
-Implementation of the 'drop' command.
-
-=head2 list_stack( $app )
-
-Implementation of the 'lstk' command.
-
-=head1 CONFIGURATION AND ENVIRONMENT
-
-App::TimelogTxt requires no environment variables.
-App::TimelogTxt will use the file ~/.timelogrc if it exists.
-
-The configuration file is expected to contain data in two major parts:
-
-=head2 General Configuration
-
-The first section defined general configuration information in a key=value
-format. The recognized keys are:
-
-=over 4
-
-=item editor
-
-The editor to use when opening the timelog file with the C<edit> command.
-If not specified, it will use the value of either the VISUAL or EDITOR
-environment variables. If non are found, it will default to C<vim>.
-
-=item dir
-
-The directory in which to find the timelog data files. Defaults to the
-C<timelog> directory in the user's home directory.
-
-=item defcmd
-
-The default command to by used if none is supplied to timelog. By default,
-this is the 'stop' command.
+[Et cetera, et cetera]
 
 =back
 
-=head2 Command Aliases
 
-The config file may also contain an '[alias]' section that defines command
-aliases. Each alias is defined as a C<shortname=expanded string>
+=head1 CONFIGURATION AND ENVIRONMENT
 
-For example, if you regularly need to make entries for reading email and
-triaging bug reports you might want the following in your configuration.
+=for author to fill in:
+    A full explanation of any configuration system(s) used by the
+    module, including the names and locations of any configuration
+    files, and the meaning of any environment variables or properties
+    that can be set. These descriptions must also include details of any
+    configuration language used.
+  
+App::TimelogTxt requires no configuration files or environment variables.
 
-  [alias]
-    email = start +Misc @Email
-    triage = start +BugTracker @Triage
 
 =head1 DEPENDENCIES
 
-App::CmdDispatch, Getopt::Long, autodie.
+=for author to fill in:
+    A list of all the other modules that this module relies upon,
+    including any restrictions on versions, and an indication whether
+    the module is part of the standard Perl distribution, part of the
+    module's distribution, or must be installed separately. ]
+
+None.
+
 
 =head1 INCOMPATIBILITIES
 
+=for author to fill in:
+    A list of any modules that this module cannot be used in conjunction
+    with. This may be due to name conflicts in the interface, or
+    competition for system or program resources, or due to internal
+    limitations of Perl (for example, many modules that use source code
+    filters are mutually incompatible).
+
 None reported.
 
+
 =head1 BUGS AND LIMITATIONS
 
+=for author to fill in:
+    A list of known problems with the module, together with some
+    indication Whether they are likely to be fixed in an upcoming
+    release. Also a list of restrictions on the features the module
+    does provide: data types that cannot be handled, performance issues
+    and the circumstances in which they may arise, practical
+    limitations on the size of data sets, special cases that are not
+    (yet) handled, etc.
+
 No bugs have been reported.
 
 Please report any bugs or feature requests to
@@ -533,11 +479,12 @@ G. Wade Johnson  C<< <gwadej@cpan.org> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2013, G. Wade Johnson C<< <gwadej@cpan.org> >>. All rights reserved.
+Copyright (c) 2013, G. Wade Johnson C<< <wade@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
