@@ -4,8 +4,8 @@ use warnings;
 use strict;
 use Time::Local;
 use App::TimelogTxt::Utils;
-
-our $VERSION = '0.03_3';
+ 
+our $VERSION = '0.03';
 
 sub new
 {
@@ -77,16 +77,24 @@ sub is_stop
     return ($_[0]->{task} eq App::TimelogTxt::Utils::STOP_CMD());
 }
 
+sub snapshot
+{
+    my ($self) = @_;
+    return %{$self};
+}
+
 1;
 __END__
 
 =head1 NAME
 
-App::TimelogTxt::Event - Class representing an event to log.
+ModName - [One line description of module's purpose here]
+
 
 =head1 VERSION
 
-This document describes ModName version 0.03_1
+This document describes ModName version 0.0.3
+
 
 =head1 SYNOPSIS
 
@@ -96,8 +104,8 @@ This document describes ModName version 0.03_1
     Brief code example(s) here showing commonest usage(s).
     This section will be as far as many users bother reading
     so make it as educational and exeplary as possible.
-
-
+  
+  
 =head1 DESCRIPTION
 
 =for author to fill in:
@@ -105,7 +113,7 @@ This document describes ModName version 0.03_1
     Use subsections (=head2, =head3) as appropriate.
 
 
-=head1 INTERFACE
+=head1 INTERFACE 
 
 =for author to fill in:
     Write a separate section listing the public components of the modules
@@ -113,33 +121,91 @@ This document describes ModName version 0.03_1
     exported, or methods that may be called on objects belonging to the
     classes provided by the module.
 
+
+=head1 DIAGNOSTICS
+
+=for author to fill in:
+    List every single error and warning message that the module can
+    generate (even the ones that will "never happen"), with a full
+    explanation of each problem, one or more likely causes, and any
+    suggested remedies.
+
+=over
+
+=item C<< Error message here, perhaps with %s placeholders >>
+
+[Description of error here]
+
+=item C<< Another error message here >>
+
+[Description of error here]
+
+[Et cetera, et cetera]
+
+=back
+
+
 =head1 CONFIGURATION AND ENVIRONMENT
 
-App::TimelogTxt::Event requires no configuration files or environment variables.
+=for author to fill in:
+    A full explanation of any configuration system(s) used by the
+    module, including the names and locations of any configuration
+    files, and the meaning of any environment variables or properties
+    that can be set. These descriptions must also include details of any
+    configuration language used.
+  
+ModName requires no configuration files or environment variables.
+
 
 =head1 DEPENDENCIES
 
-Time:Local.
+=for author to fill in:
+    A list of all the other modules that this module relies upon,
+    including any restrictions on versions, and an indication whether
+    the module is part of the standard Perl distribution, part of the
+    module's distribution, or must be installed separately. ]
+
+None.
+
 
 =head1 INCOMPATIBILITIES
 
+=for author to fill in:
+    A list of any modules that this module cannot be used in conjunction
+    with. This may be due to name conflicts in the interface, or
+    competition for system or program resources, or due to internal
+    limitations of Perl (for example, many modules that use source code
+    filters are mutually incompatible).
+
 None reported.
 
+
 =head1 BUGS AND LIMITATIONS
 
+=for author to fill in:
+    A list of known problems with the module, together with some
+    indication Whether they are likely to be fixed in an upcoming
+    release. Also a list of restrictions on the features the module
+    does provide: data types that cannot be handled, performance issues
+    and the circumstances in which they may arise, practical
+    limitations on the size of data sets, special cases that are not
+    (yet) handled, etc.
+
 No bugs have been reported.
 
 =head1 AUTHOR
 
-G. Wade Johnson  C<< gwadej@cpan.org >>
+G. Wade Johnson  C<< wade@anomaly.org >>
+
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2013, G. Wade Johnson C<< gwadej@cpan.org >>. All rights reserved.
+Copyright (c) <YEAR>, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
